@@ -2,8 +2,8 @@
 __title__ = "mysql-to-sqlite3"
 __description__ = "A simple Python tool to transfer data from MySQL to SQLite 3"
 __url__ = "https://github.com/techouse/mysql-to-sqlite3"
-__version__ = "1.3.1"
-__author__ = "Klemen Tušar"
+__version__ = "1.3.2"
+__author__ = "Klemen Tusar"
 __author_email__ = "techouse@gmail.com"
 __license__ = "MIT"
-__copyright__ = "Copyright 2020 Klemen Tušar"
+__copyright__ = "Copyright 2020 Klemen Tusar"
